MigratedUserAttachRowRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

newAuthUser(DatabaseSession session, MigratedUser migratedUser, AuthUser newAuthUser, {Transaction? transaction}) Future<void>
Creates a relation between the given MigratedUser and AuthUser by setting the MigratedUser's foreign key newAuthUserId to refer to the AuthUser.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
oldUser(DatabaseSession session, MigratedUser migratedUser, UserInfo oldUser, {Transaction? transaction}) Future<void>
Creates a relation between the given MigratedUser and UserInfo by setting the MigratedUser's foreign key oldUserId to refer to the UserInfo.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited